<div align="center">
  <img src="./docs/logo.png" width="600"/>
</div>
<br />

[![docs](https://img.shields.io/badge/docs-latest-blue)]()
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sciogovterminal)](https://pypi.org/project/sciogovterminal/)
[![PyPI](https://img.shields.io/pypi/v/sciogovterminal)](https://pypi.org/project/sciogovterminal)
[![license](https://img.shields.io/github/license/CharlesPikachu/sciogovterminal.svg)](https://github.com/CharlesPikachu/sciogovterminal/blob/master/LICENSE)
[![PyPI - Downloads](https://pepy.tech/badge/sciogovterminal)](https://pypi.org/project/sciogovterminal/)
[![issue resolution](https://isitmaintained.com/badge/resolution/CharlesPikachu/sciogovterminal.svg)](https://github.com/CharlesPikachu/sciogovterminal/issues)
[![open issues](https://isitmaintained.com/badge/open/CharlesPikachu/sciogovterminal.svg)](https://github.com/CharlesPikachu/sciogovterminal/issues)

Introduction: 


# Sciogovterminal
```
Sciogovterminal: Browse "The State Council Information Office of the People's Republic of China" in the terminal.
You can star this repository to keep track of the project if it's helpful for you, thank you for your support.
```


# Install

#### Pip install
```
run "pip install sciogovterminal"
```

#### Source code install
```sh
(1) Offline
Step1: git clone https://github.com/CharlesPikachu/sciogovterminal.git
Step2: cd sciogovterminal -> run "python setup.py install"
(2) Online
run "pip install git+https://github.com/CharlesPikachu/sciogovterminal.git@master"
```


# Quick Start

After installing sciogovterminal, you can execute the command in the terminal like:

```
sciogov -i http://www.scio.gov.cn/m/37234/Document/1720965/1720965.htm
```

Then, you can browse [《2021年美国侵犯人权报告》](http://www.scio.gov.cn/m/37234/Document/1720965/1720965.htm) in the terminal as follows:

![img](./docs/screenshot.gif)


# Projects in Charles_pikachu
- [Games](https://github.com/CharlesPikachu/Games): Create interesting games by pure python.
- [DecryptLogin](https://github.com/CharlesPikachu/DecryptLogin): APIs for loginning some websites by using requests.
- [Musicdl](https://github.com/CharlesPikachu/musicdl): A lightweight music downloader written by pure python.
- [Videodl](https://github.com/CharlesPikachu/videodl): A lightweight video downloader written by pure python.
- [Pytools](https://github.com/CharlesPikachu/pytools): Some useful tools written by pure python.
- [PikachuWeChat](https://github.com/CharlesPikachu/pikachuwechat): Play WeChat with itchat-uos.
- [Pydrawing](https://github.com/CharlesPikachu/pydrawing): Beautify your image or video.
- [ImageCompressor](https://github.com/CharlesPikachu/imagecompressor): Image compressors written by pure python.
- [FreeProxy](https://github.com/CharlesPikachu/freeproxy): Collecting free proxies from internet.
- [Paperdl](https://github.com/CharlesPikachu/paperdl): Search and download paper from specific websites.


# More
#### WeChat Official Accounts
*Charles_pikachu*  
![img](./docs/pikachu.jpg)